::--------------------------------------------------
:: Runs this project's Java program(s).
::
:: WARNING: when set the variables below, DO NOT DO A BLANK ASSIGNMENT like set someVar=
:: if someVar is not currently an environmental variable, since in dos that will set errorlevel to 1
::--------------------------------------------------


::----------define global environment variables


@call globalEnvVars.bat
if errorlevel 1 goto handleError


::----------define environment variables specific to this file


set assertions=-enableassertions  -enablesystemassertions
::set assertions=-disableassertions  -disablesystemassertions

::set errorHandling=-XX:+ShowMessageBoxOnError
set errorHandling=-XX:OnError="userdump.exe %%p"
::--------------------CRITICAL: used %%p above because in dos must escape the % char if use it in an env var
::--------------------To understand the above, see:
::	http://java.sun.com/j2se/1.5/pdf/jdk50_ts_guide.pdf Section 3.2.4 starting at page 40 and 121
::	http://support.microsoft.com/?kbid=241215
::	http://download.microsoft.com/download/win2000srv/Utility/3.0/NT45/EN-US/Oem3sr2.zip
::	http://www-128.ibm.com/developerworks/java/library/j-tiger03175.html
set errorHandling=%errorHandling%  -XX:+HeapDumpOnOutOfMemoryError

::--------------------throughput collectors:
::set gcType=-XX:+AggressiveHeap
set gcType=-XX:+UseParallelGC  -XX:+UseParallelOldGC
::--------------------low pause collectors:
::set gcType=-XX:MaxGCPauseMillis=nnn 
::set gcType=-XX:+UseConcMarkSweepGC  -XX:+UseParNewGC
::--------------------gc logging:
::set gcType=-Xloggc:./gcLog.txt  -XX:+PrintGCDetails  -XX:+PrintGCTimeStamps
::--------------------documentation on the gc options above:
::	http://java.sun.com/javase/technologies/hotspot/gc/index.jsp
::	http://java.sun.com/javase/technologies/hotspot/gc/gc_tuning_6.html
::	http://java.sun.com/j2se/1.5.0/docs/guide/vm/gc-ergonomics.html
::	http://www.folgmann.de/en/j2ee/gc.html
::	http://java.sun.com/docs/hotspot/gc1.4.2/faq.html

set jni=-Xcheck:jni

::set logConfig=-Djava.util.logging.config.file=./logging.properties
  
::set memory=-Xms64m -Xmx1250m

::set performance=-XX:+AggressiveOpts

::set vmType=-client
set vmType=-server

set standardJavaOptions=%assertions%  -classpath %classPath%  %errorHandling%  %gcType%  %jni%  %logConfig%  %memory%  %performance%  %vmType%  -Xfuture


::set profiling=-javaagent:%libDir%/jip-profile.jar


if errorlevel 1 goto handleError


::----------run program(s)


echo on

@echo.
@echo ==================================================

java  %standardJavaOptions%  N01_Part1_Listing1
::java  %standardJavaOptions%  N02_Part1_Listing2
::java  %standardJavaOptions%  N03_Part1_Listing4
::java  %standardJavaOptions%  N04_Part1_Listing5
::java  %standardJavaOptions%  N05_Part1_Listing7

::java  %standardJavaOptions%  N06_Part2_Figures1and2
::java  %standardJavaOptions%  N07_Part2_Listing1
::java  %standardJavaOptions%  N08_Part2_DataStructureAccess  1024  Sequential
::java  %standardJavaOptions%  N08_Part2_DataStructureAccess  1048576  Sequential
::java  %standardJavaOptions%  N08_Part2_DataStructureAccess  1024  Random
::java  %standardJavaOptions%  N08_Part2_DataStructureAccess  1048576  Random

:: -----single arg invocations cause calls to N09_Part2_PortfolioOptimization.test_manyFunctionalities:
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_australianFunds_monthly_2005-2007.txt
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_oex_monthly_2005-2007.txt
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_oex_weekly_2005-2007.txt
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_vanguard_yearly_1998-2007.txt
:: -----double arg invocations cause calls to N09_Part2_PortfolioOptimization.benchmark_efficientFrontier:
:: ----------no constraints:
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_australianFunds_monthly_2005-2007.txt  NOConstraints
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_oex_monthly_2005-2007.txt  NOConstraints
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_oex_weekly_2005-2007.txt  NOConstraints
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_vanguard_yearly_1998-2007.txt  NOConstraints
:: ----------constraints:
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_australianFunds_monthly_2005-2007.txt  useConstraints
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_oex_monthly_2005-2007.txt  useConstraints
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_oex_weekly_2005-2007.txt  useConstraints
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_vanguard_yearly_1998-2007.txt  useConstraints

::java  %standardJavaOptions%  N10_Supplement_Lfsr
::java  %standardJavaOptions%  N11_Supplement_LfsrVariations
::java  %standardJavaOptions%  N12_Supplement_Listing3
::java  %standardJavaOptions%  N13_Supplement_CallableVersusRunnable

@if errorlevel 1 goto handleError

@echo off

:: TO DO CODE PROFILING, read: D:\software\java\docsGroupedByTopic\performance\profiling.txt


::----------error handling and final actions:


:handleError
@if not errorlevel 1 goto finalActions
@echo.
@echo ERROR DETECTED: jr.bat will TERMINATE PREMATURELY

:finalActions
@echo off
