#!/bin/sh
set -e	# exit on first failed command
set -u	# exit if encounter never set variable


#--------------------------------------------------
# Runs this project's Java program(s).
#--------------------------------------------------


#----------define global environment variables


. ./globalEnvVars.sh


#----------define environment variables specific to this file


assertions="-enableassertions  -enablesystemassertions"
#assertions="-disableassertions  -disablesystemassertions"

errorHandling=-XX:+ShowMessageBoxOnError
#errorHandling=-XX:OnError=\"gdb\ -\ %p\"
# +++ commented out the above and fell back to first line because it fails in cygwin due to bash splitting it into multiple words; not sure why, as this should work...
#--------------------To understand the above, see:
#	http://java.sun.com/j2se/1.5/pdf/jdk50_ts_guide.pdf Section 3.2.4 starting at page 40 and 121
#	http://support.microsoft.com/?kbid=241215
#	http://download.microsoft.com/download/win2000srv/Utility/3.0/NT45/EN-US/Oem3sr2.zip
#	http://www-128.ibm.com/developerworks/java/library/j-tiger03175.html
errorHandling="$errorHandling  -XX:+HeapDumpOnOutOfMemoryError"

#--------------------throughput collectors:
#gcType="-XX:+AggressiveHeap"
gcType="-XX:+UseParallelGC  -XX:+UseParallelOldGC"
#--------------------low pause collectors:
#gcType="-XX:MaxGCPauseMillis=nnn"
#gcType="-XX:+UseConcMarkSweepGC  -XX:+UseParNewGC"
#--------------------gc logging:
#gcType="-Xloggc:./gcLog.txt  -XX:+PrintGCDetails  -XX:+PrintGCTimeStamps"
#--------------------documentation on the gc options above:
#	http://java.sun.com/javase/technologies/hotspot/gc/index.jsp
#	http://java.sun.com/javase/technologies/hotspot/gc/gc_tuning_6.html
#	http://java.sun.com/j2se/1.5.0/docs/guide/vm/gc-ergonomics.html
#	http://www.folgmann.de/en/j2ee/gc.html
#	http://java.sun.com/docs/hotspot/gc1.4.2/faq.html

jni=-Xcheck:jni

logConfig=""
#logConfig=-Djava.util.logging.config.file=./logging.properties

memory=""
#memory="-Xms64m -Xmx1250m"

performance=""
#performance=-XX:+AggressiveOpts

#vmType=-client
vmType=-server

standardJavaOptions="$assertions  -classpath $classPath  $errorHandling  $gcType  $jni  $logConfig  $memory  $performance  $vmType  -Xfuture"


profiling=""
#profiling=-javaagent:$libDir/jip-profile.jar


#--------------------start something with low priority (e.g. use if program is making machine unresponsive when run at higher priority):
startWithLowPriority="nice  -n 19"
#--------------------typical usage: $startWithLowPriority java ...


#----------run program(s)

echo
echo "=================================================="
echo

java  $standardJavaOptions  N01_Part1_Listing1
#java  $standardJavaOptions  N02_Part1_Listing2
#java  $standardJavaOptions  N03_Part1_Listing4
#java  $standardJavaOptions  N04_Part1_Listing5
#java  $standardJavaOptions  N05_Part1_Listing7

#java  $standardJavaOptions  N06_Part2_Figures1and2
#java  $standardJavaOptions  N07_Part2_Listing1
#java  $standardJavaOptions  N08_Part2_DataStructureAccess  1024  Sequential
#java  $standardJavaOptions  N08_Part2_DataStructureAccess  1048576  Sequential
#java  $standardJavaOptions  N08_Part2_DataStructureAccess  1024  Random
#java  $standardJavaOptions  N08_Part2_DataStructureAccess  1048576  Random

# -----single arg invocations cause calls to N09_Part2_PortfolioOptimization.test_manyFunctionalities:
#java  $standardJavaOptions  N09_Part2_PortfolioOptimization  ../data/returns_australianFunds_monthly_2005-2007.txt
#java  $standardJavaOptions  N09_Part2_PortfolioOptimization  ../data/returns_oex_monthly_2005-2007.txt
#java  $standardJavaOptions  N09_Part2_PortfolioOptimization  ../data/returns_oex_weekly_2005-2007.txt
#java  $standardJavaOptions  N09_Part2_PortfolioOptimization  ../data/returns_vanguard_yearly_1998-2007.txt
# -----double arg invocations cause calls to N09_Part2_PortfolioOptimization.benchmark_efficientFrontier:
# ----------no constraints:
#java  $standardJavaOptions  N09_Part2_PortfolioOptimization  ../data/returns_australianFunds_monthly_2005-2007.txt  NOConstraints
#java  $standardJavaOptions  N09_Part2_PortfolioOptimization  ../data/returns_oex_monthly_2005-2007.txt  NOConstraints
#java  $standardJavaOptions  N09_Part2_PortfolioOptimization  ../data/returns_oex_weekly_2005-2007.txt  NOConstraints
#java  $standardJavaOptions  N09_Part2_PortfolioOptimization  ../data/returns_vanguard_yearly_1998-2007.txt  NOConstraints
# ----------constraints:
#java  $standardJavaOptions  N09_Part2_PortfolioOptimization  ../data/returns_australianFunds_monthly_2005-2007.txt  useConstraints
#java  $standardJavaOptions  N09_Part2_PortfolioOptimization  ../data/returns_oex_monthly_2005-2007.txt  useConstraints
#java  $standardJavaOptions  N09_Part2_PortfolioOptimization  ../data/returns_oex_weekly_2005-2007.txt  useConstraints
#java  $standardJavaOptions  N09_Part2_PortfolioOptimization  ../data/returns_vanguard_yearly_1998-2007.txt  useConstraints

#java  $standardJavaOptions  N10_Supplement_Lfsr
#java  $standardJavaOptions  N11_Supplement_LfsrVariations
#java  $standardJavaOptions  N12_Supplement_Listing3
#java  $standardJavaOptions  N13_Supplement_CallableVersusRunnable

# TO DO CODE PROFILING, read: D:/software/java/docsGroupedByTopic/performance/profiling.txt
