/*
Copyright  2008 Brent Boyer

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Lesser GNU General Public License for more details.

You should have received a copy of the Lesser GNU General Public License along with this program (see the license directory in this project).  If not, see <http://www.gnu.org/licenses/>.
*/


import bb.util.Benchmark;


/**
* For the article <a href="http://www.ibm.com/developerworks/java/library/j-benchmark1.html">Robust Java benchmarking, Part 1: Issues</a>,
* contains the code relevant to <a href="http://www.ibm.com/developerworks/java/library/j-benchmark1.html#listing2">Listing 2</a>.
* <p>
* @author Brent Boyer
*/
public class N02_Part1_Listing2 extends N01_Part1_Listing1 {
	
	
	/**
	* Results on 2008/3/27 on my 2.2 GHz Intel Core 2 Duo E4500 machine (server jvm):
	* <pre><code>
		a): Cliff Click microbenchmark: first = 34.118 ms, mean = 20.111 ms (CI deltas: -11.454 us, +36.843 us), sd = 590.476 us (CI deltas: -381.576 us, +693.754 us) WARNING: EXECUTION TIMES HAVE EXTREME OUTLIERS, SD VALUES MAY BE INACCURATE
		b): Cliff Click microbenchmark: first = 33.778 ms, mean = 20.021 ms (CI deltas: -1.612 us, +1.644 us), sd = 52.232 us (CI deltas: -7.359 us, +10.325 us) WARNING: SD VALUES MAY BE INACCURATE
		c): Cliff Click microbenchmark: first = 33.924 ms, mean = 26.649 ms (CI deltas: -4.019 us, +4.278 us), sd = 132.990 us (CI deltas: -18.550 us, +23.984 us) WARNING: SD VALUES MAY BE INACCURATE
		d): Cliff Click microbenchmark: first = 33.895 ms, mean = 26.654 ms (CI deltas: +-3.601 us), sd = 115.405 us (CI deltas: -17.173 us, +26.319 us) WARNING: execution times have mild outliers, SD VALUES MAY BE INACCURATE
	</code></pre>
	*/
	public static void main(String[] args) throws Exception {
		System.out.println();
		System.out.println("N02_Part1_Listing2:");
		
		Runnable task = new Runnable() { public void run() {
			int value = 0;
			for (int i = 0; i < 100 * 1000 * 1000; i++) {
				value = calculate(value);
			}
		} };
			// Note: to guarantee no DCE, if you followed the advice in the article,
			// SHOULD change value above from a local variable to a field and add
			//	@Override public String toString() { return String.valueOf(value); }
			// This was not done in the article simply to avoid throwing too much material at the reader too soon.
			// Plus, the sane results that I obtained seem to indicate that DCE is not happening here
			// (presumably because the global field is modified by calculate).
		
		System.out.println("Cliff Click microbenchmark: " + new Benchmark(task));
	}
	
	
}