/*
Copyright  2008 Brent Boyer

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Lesser GNU General Public License for more details.

You should have received a copy of the Lesser GNU General Public License along with this program (see the license directory in this project).  If not, see <http://www.gnu.org/licenses/>.
*/


/**
* For the article <a href="http://www.ibm.com/developerworks/java/library/j-benchmark1.html">Robust Java benchmarking, Part 1: Issues</a>,
* contains the code relevant to <a href="http://www.ibm.com/developerworks/java/library/j-benchmark1.html#listing5">Listing 5</a>.
* <p>
* @author Brent Boyer
*/
public class N04_Part1_Listing5 extends N03_Part1_Listing4 {
	
	
	/**
	* Results on 2008/3/27 on my 2.2 GHz Intel Core 2 Duo E4500 machine (server jvm):
	* <pre><code>
		Execution time = 10.81... seconds to compute result = 1580674560
		Execution time = 10.79... seconds to compute result = 1580674560
		Execution time = 10.80... seconds to compute result = 1580674560
	</code></pre>
	*/
	public static void main(String[] args) {
		System.out.println();
		System.out.println("N04_Part1_Listing5:");
		
		long t1 = System.nanoTime();
		
		int result = 0;
		for (int i = 0; i < 1000 * 1000; i++) {	// sole loop
			result = add(result);
			result = xor(result);
		}
		
		long t2 = System.nanoTime();
		System.out.println("Execution time: " + ((t2 - t1) * 1e-9) + " seconds to compute result = " + result);
	}
	
	
	protected static int add(int result) {	// method extraction of inner loop 1
		for (int j = 0; j < array.length; j++) {
			result += array[j];
		}
		return result;
	}
	
	
	protected static int xor(int result) {	// method extraction of inner loop 2
		for (int j = 0; j < array.length; j++) {
			result ^= array[j];
		}
		return result;
	}
	
	
}