/*
Copyright  2008 Brent Boyer

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Lesser GNU General Public License for more details.

You should have received a copy of the Lesser GNU General Public License along with this program (see the license directory in this project).  If not, see <http://www.gnu.org/licenses/>.
*/


import java.util.concurrent.Callable;

import bb.util.Benchmark;


/**
* For the <a href="http://www.ellipticgroup.com/html/benchmarkingArticle.html">article supplement</a>,
* contains the code relevant to Listing 3.
* <p>
* @author Brent Boyer
*/
public class N12_Supplement_Listing3 {
	
	
	/**
	* Results on 2008/3/27 on my 2.2 GHz Intel Core 2 Duo E4500 machine (server jvm):
	* <pre><code>
		StringBuilder.replace: action statistics: first = 36.415 us, mean = 20.437 ns (CI deltas: -5.229 ps, +5.084 ps), sd = 168.910 ns (CI deltas: -22.590 ns, +32.759 ns) WARNING: SD VALUES MAY BE INACCURATE
			----------
			--the action statistics were calculated from block statistics
			--each block measured 67108864 task executions
			--the user says that task internally performs m = 1 actions
			--then the number of actions per block measurement is a = 67108864
			--block statistics: mean = 1.371 s (CI deltas: -350.914 us, +341.209 us), sd = 1.384 ms (CI deltas: -185.055 us, +268.364 us)
			--the forumla used to convert block statistics to action statistics (mean scales as 1/a, sd scales as 1/sqrt(a)) assumes that the execution times are iid
			----------
			--each confidence interval (CI) is reported as either +- deltas from the point estimate, or as a closed interval ([x, y])
			--each confidence interval has confidence level = 0.95
			----------
			--block sd values MAY NOT REFLECT TASK'S INTRINSIC VARIATION
			--guesstimate: environmental noise explains at least 39.97561339191399% of the measured sd
			----------
			--action sd values ALMOST CERTAINLY GROSSLY INFLATED by outliers
			--they cause at least 98.46707644931065% of the measured VARIANCE according to one equi-valued outlier model
	</code></pre>
	*/
	public static void main(String[] args) throws Exception {
		System.out.println();
		System.out.println("N12_Supplement_Listing3:");
		
		final StringBuilder sb = new StringBuilder("Yes");
		Callable<StringBuilder> task = new Callable<StringBuilder>() {
			public StringBuilder call() { return sb.length() == 3 ? sb.replace(0, 3, "No") : sb.replace(0, 2, "Yes"); }
		};
		System.out.println("StringBuilder.replace: " + new Benchmark(task).toStringFull());
	}
	
	
}