/*
Copyright  2008 Brent Boyer

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Lesser GNU General Public License for more details.

You should have received a copy of the Lesser GNU General Public License along with this program (see the license directory in this project).  If not, see <http://www.gnu.org/licenses/>.
*/


import java.util.Random;
import java.util.concurrent.Callable;

import bb.util.Benchmark;


/**
* For the <a href="http://www.ellipticgroup.com/html/benchmarkingArticle.html">article supplement</a>,
* contains the code relevant to Listing 4 and Listing 5.
* <p>
* @author Brent Boyer
*/
public class N13_Supplement_CallableVersusRunnable {
	
	
	/**
	* Results on 2008/3/27 on my 2.2 GHz Intel Core 2 Duo E4500 machine (server jvm):
	* see this file: <code>../results/N13_Supplement_CallableVersusRunnable.txt</code>
	*/
	public static void main(String[] args) throws Exception {
		System.out.println();
		System.out.println("N13_Supplement_CallableVersusRunnable:");
		
		Callable<Integer> taskAsCallable1 = new Callable<Integer>() { public Integer call() { return N07_Part2_Listing1.fibonacci(5); } };
		System.out.println("Callable fibonacci(5): " + new Benchmark(taskAsCallable1).toStringFull());
		
		Runnable taskAsRunnable1 = new Runnable() {
			private int sumOfResults = 0;
			public void run() {
				sumOfResults += N07_Part2_Listing1.fibonacci(5);
			}
			@Override public String toString() { return "sumOfResults = " + sumOfResults; }
		};
		System.out.println("Runnable fibonacci(5): " + new Benchmark(taskAsRunnable1).toStringFull());
		
		final Random random = new Random();
		
		Callable<Integer> taskAsCallable2 = new Callable<Integer>() { public Integer call() { return random.nextInt(); } };
		System.out.println("Callable random.nextInt: " + new Benchmark(taskAsCallable2).toStringFull());
		
		Runnable taskAsRunnable2 = new Runnable() {
			private int sumOfResults = 0;
			public void run() {
				sumOfResults += random.nextInt();
			}
			@Override public String toString() { return "sumOfResults = " + sumOfResults; }
		};
		System.out.println("Runnable random.nextInt: " + new Benchmark(taskAsRunnable2).toStringFull());
	}
	
	
}